==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/SM_SMSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ClassStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.InstanceStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.List;


public class SM_SMSetImpl extends InstanceSet<SM_SMSet,SM_SM> implements SM_SMSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId m_SM_ID ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setSM_ID( m_SM_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setDescrip( m_Descrip );
    }
    @Override
    public void setConfig_ID( int m_Config_ID ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setConfig_ID( m_Config_ID );
    }


    // selections
    @Override
    public StateMachineStateSet R501_is_decomposed_into_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( SM_SM sm_sm : this ) statemachinestateset.addAll( sm_sm.R501_is_decomposed_into_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public StateMachineEventSet R502_can_be_communicated_to_via_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( SM_SM sm_sm : this ) statemachineeventset.addAll( sm_sm.R502_can_be_communicated_to_via_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public TransitionSet R505_contains_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( SM_SM sm_sm : this ) transitionset.addAll( sm_sm.R505_contains_Transition() );
        return transitionset;
    }
    @Override
    public MealyStateMachineSet R510_is_a_MealyStateMachine() throws XtumlException {
        MealyStateMachineSet mealystatemachineset = new MealyStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) mealystatemachineset.add( sm_sm.R510_is_a_MealyStateMachine() );
        return mealystatemachineset;
    }
    @Override
    public MooreStateMachineSet R510_is_a_MooreStateMachine() throws XtumlException {
        MooreStateMachineSet moorestatemachineset = new MooreStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) moorestatemachineset.add( sm_sm.R510_is_a_MooreStateMachine() );
        return moorestatemachineset;
    }
    @Override
    public ActionSet R515_contains_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( SM_SM sm_sm : this ) actionset.addAll( sm_sm.R515_contains_Action() );
        return actionset;
    }
    @Override
    public StateMachineEventDataItemSet R516_can_asynchronously_communicate_via_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( SM_SM sm_sm : this ) statemachineeventdataitemset.addAll( sm_sm.R516_can_asynchronously_communicate_via_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public ClassStateMachineSet R517_is_a_ClassStateMachine() throws XtumlException {
        ClassStateMachineSet classstatemachineset = new ClassStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) classstatemachineset.add( sm_sm.R517_is_a_ClassStateMachine() );
        return classstatemachineset;
    }
    @Override
    public InstanceStateMachineSet R517_is_a_InstanceStateMachine() throws XtumlException {
        InstanceStateMachineSet instancestatemachineset = new InstanceStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) instancestatemachineset.add( sm_sm.R517_is_a_InstanceStateMachine() );
        return instancestatemachineset;
    }


    @Override
    public SM_SM nullElement() {
        return SM_SMImpl.EMPTY_SM_SM;
    }

    @Override
    public SM_SMSet emptySet() {
      return new SM_SMSetImpl();
    }

    @Override
    public SM_SMSet value() {
        return this;
    }

    @Override
    public List<SM_SM> elements() {
        return Arrays.asList(toArray(new SM_SM[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/SM_SMSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ClassStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.InstanceStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SM_SMSetImpl extends InstanceSet<SM_SMSet,SM_SM> implements SM_SMSet {

    public SM_SMSetImpl() {
    }

    public SM_SMSetImpl(Comparator<? super SM_SM> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId m_SM_ID ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setSM_ID( m_SM_ID );
    }
    @Override
    public void setConfig_ID( int m_Config_ID ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setConfig_ID( m_Config_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SM_SM sm_sm : this ) sm_sm.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public StateMachineStateSet R501_is_decomposed_into_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( SM_SM sm_sm : this ) statemachinestateset.addAll( sm_sm.R501_is_decomposed_into_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public StateMachineEventSet R502_can_be_communicated_to_via_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( SM_SM sm_sm : this ) statemachineeventset.addAll( sm_sm.R502_can_be_communicated_to_via_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public TransitionSet R505_contains_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( SM_SM sm_sm : this ) transitionset.addAll( sm_sm.R505_contains_Transition() );
        return transitionset;
    }
    @Override
    public MealyStateMachineSet R510_is_a_MealyStateMachine() throws XtumlException {
        MealyStateMachineSet mealystatemachineset = new MealyStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) mealystatemachineset.add( sm_sm.R510_is_a_MealyStateMachine() );
        return mealystatemachineset;
    }
    @Override
    public MooreStateMachineSet R510_is_a_MooreStateMachine() throws XtumlException {
        MooreStateMachineSet moorestatemachineset = new MooreStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) moorestatemachineset.add( sm_sm.R510_is_a_MooreStateMachine() );
        return moorestatemachineset;
    }
    @Override
    public ActionSet R515_contains_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( SM_SM sm_sm : this ) actionset.addAll( sm_sm.R515_contains_Action() );
        return actionset;
    }
    @Override
    public StateMachineEventDataItemSet R516_can_asynchronously_communicate_via_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( SM_SM sm_sm : this ) statemachineeventdataitemset.addAll( sm_sm.R516_can_asynchronously_communicate_via_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public ClassStateMachineSet R517_is_a_ClassStateMachine() throws XtumlException {
        ClassStateMachineSet classstatemachineset = new ClassStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) classstatemachineset.add( sm_sm.R517_is_a_ClassStateMachine() );
        return classstatemachineset;
    }
    @Override
    public InstanceStateMachineSet R517_is_a_InstanceStateMachine() throws XtumlException {
        InstanceStateMachineSet instancestatemachineset = new InstanceStateMachineSetImpl();
        for ( SM_SM sm_sm : this ) instancestatemachineset.add( sm_sm.R517_is_a_InstanceStateMachine() );
        return instancestatemachineset;
    }


    @Override
    public SM_SM nullElement() {
        return SM_SMImpl.EMPTY_SM_SM;
    }

    @Override
    public SM_SMSet emptySet() {
      return new SM_SMSetImpl();
    }

    @Override
    public SM_SMSet emptySet(Comparator<? super SM_SM> comp) {
      return new SM_SMSetImpl(comp);
    }

    @Override
    public SM_SMSet value() {
        return this;
    }

    @Override
    public List<SM_SM> elements() {
        return Arrays.asList(toArray(new SM_SM[0]));
    }

}
